@@ -20,6 +20,7 @@ from botocore.response import StreamingBody
 from .literals import (
     AuthMechanismValueType,
     AuthTypeValueType,
+    CannedAclForObjectsValueType,
     CharLengthSemanticsType,
     CompressionTypeValueType,
     DataFormatValueType,
@@ -35,10 +36,12 @@ from .literals import (
     NestingLevelValueType,
     ParquetVersionValueType,
     PluginNameValueType,
+    RedisAuthTypeValueType,
     RefreshSchemasStatusTypeValueType,
     ReloadOptionValueType,
     ReplicationEndpointTypeValueType,
     SafeguardPolicyType,
+    SslSecurityProtocolValueType,
     StartReplicationTaskTypeValueType,
     TargetDbTypeType,
 )
@@ -171,6 +174,7 @@ __all__ = (
     "PostgreSQLSettingsTypeDef",
     "RebootReplicationInstanceMessageRequestTypeDef",
     "RebootReplicationInstanceResponseTypeDef",
+    "RedisSettingsTypeDef",
     "RedshiftSettingsTypeDef",
     "RefreshSchemasMessageRequestTypeDef",
     "RefreshSchemasResponseTypeDef",
@@ -339,6 +343,7 @@ _OptionalCreateEndpointMessageRequestTypeDef = TypedDict(
         "IBMDb2Settings": "IBMDb2SettingsTypeDef",
         "ResourceIdentifier": str,
         "DocDbSettings": "DocDbSettingsTypeDef",
+        "RedisSettings": "RedisSettingsTypeDef",
     },
     total=False,
 )
@@ -1200,6 +1205,7 @@ EndpointTypeDef = TypedDict(
         "MicrosoftSQLServerSettings": "MicrosoftSQLServerSettingsTypeDef",
         "IBMDb2Settings": "IBMDb2SettingsTypeDef",
         "DocDbSettings": "DocDbSettingsTypeDef",
+        "RedisSettings": "RedisSettingsTypeDef",
     },
     total=False,
 )
@@ -1343,7 +1349,9 @@ ListTagsForResourceMessageRequestTypeDef = TypedDict(
     "ListTagsForResourceMessageRequestTypeDef",
     {
         "ResourceArn": str,
+        "ResourceArnList": List[str],
     },
+    total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
@@ -1413,6 +1421,7 @@ _OptionalModifyEndpointMessageRequestTypeDef = TypedDict(
         "MicrosoftSQLServerSettings": "MicrosoftSQLServerSettingsTypeDef",
         "IBMDb2Settings": "IBMDb2SettingsTypeDef",
         "DocDbSettings": "DocDbSettingsTypeDef",
+        "RedisSettings": "RedisSettingsTypeDef",
         "ExactSettings": bool,
     },
     total=False,
@@ -1661,6 +1670,7 @@ OracleSettingsTypeDef = TypedDict(
         "AddSupplementalLogging": bool,
         "ArchivedLogDestId": int,
         "AdditionalArchivedLogDestId": int,
+        "ExtraArchivedLogDestIds": List[int],
         "AllowSelectNestedTables": bool,
         "ParallelAsmReadThreads": int,
         "ReadAheadBlocks": int,
@@ -1795,6 +1805,30 @@ RebootReplicationInstanceResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredRedisSettingsTypeDef = TypedDict(
+    "_RequiredRedisSettingsTypeDef",
+    {
+        "ServerName": str,
+        "Port": int,
+    },
+)
+_OptionalRedisSettingsTypeDef = TypedDict(
+    "_OptionalRedisSettingsTypeDef",
+    {
+        "SslSecurityProtocol": SslSecurityProtocolValueType,
+        "AuthType": RedisAuthTypeValueType,
+        "AuthUserName": str,
+        "AuthPassword": str,
+        "SslCaCertificateArn": str,
+    },
+    total=False,
+)
+
+
+class RedisSettingsTypeDef(_RequiredRedisSettingsTypeDef, _OptionalRedisSettingsTypeDef):
+    pass
+
+
 RedshiftSettingsTypeDef = TypedDict(
     "RedshiftSettingsTypeDef",
     {
@@ -2110,6 +2144,14 @@ S3SettingsTypeDef = TypedDict(
         "CsvNoSupValue": str,
         "PreserveTransactions": bool,
         "CdcPath": str,
+        "CannedAclForObjects": CannedAclForObjectsValueType,
+        "AddColumnName": bool,
+        "CdcMaxBatchInterval": int,
+        "CdcMinFileSize": int,
+        "CsvNullValue": str,
+        "IgnoreHeaderRows": int,
+        "MaxFileSize": int,
+        "Rfc4180": bool,
     },
     total=False,
 )
@@ -2289,6 +2331,7 @@ TagTypeDef = TypedDict(
     {
         "Key": str,
         "Value": str,
+        "ResourceArn": str,
     },
     total=False,
 )
